@@ -36,7 +36,6 @@
  * ---------------------------------------------------------------------- -->*/
 
 #include <sbml/common/common.h>
-#include <sbml/math/FormulaFormatter.h>
 #include <sbml/math/L3FormulaFormatter.h>
 #include <sbml/math/L3ParserSettings.h>
 #include <sbml/math/ASTNode.h>
@@ -44,12 +43,6 @@
 
 #include <sbml/util/util.h>
 
-int
-L3FormulaFormatter_hasUnambiguousGrammar(const ASTNode_t *node, 
-                               const ASTNode_t *child, 
-                               const L3ParserSettings_t *settings);
-
-
 /** @cond doxygenIgnored */
 LIBSBML_EXTERN
 char *
@@ -67,13 +60,14 @@ char *
 SBML_formulaToL3StringWithSettings (const ASTNode_t *tree, const L3ParserSettings_t *settings)
 {
   char           *s;
-  StringBuffer_t *sb = StringBuffer_create(128);
+  StringBuffer_t *sb;
 
   if (tree == NULL)
   {
     return NULL;
   }
 
+  sb = StringBuffer_create(128);
   L3FormulaFormatter_visit(NULL, tree, sb, settings);
   s = StringBuffer_getBuffer(sb);
   safe_free(sb);
@@ -261,9 +255,6 @@ int getL3Precedence(const ASTNode_t* node)
         }
         break;
 
-      case AST_ORIGINATES_IN_PACKAGE:
-        precedence = ASTNode_getL3PackageInfixPrecedence(node);
-        break;
       default:
         precedence = 8;
         break;
@@ -299,7 +290,7 @@ L3FormulaFormatter_isGrouped (const ASTNode_t *parent, const ASTNode_t *child, c
   if (parent != NULL)
   {
     parentmodulo = isTranslatedModulo(parent);
-    if (parentmodulo || !L3FormulaFormatter_hasUnambiguousGrammar(parent, child, settings))
+    if (parentmodulo || !L3FormulaFormatter_isFunction(parent, settings))
     {
       group = 1;
       pp = getL3Precedence(parent);
@@ -325,12 +316,13 @@ L3FormulaFormatter_isGrouped (const ASTNode_t *parent, const ASTNode_t *child, c
          */
         if (ASTNode_getLeftChild(parent) == child)
         {
-          pt = ASTNode_getType(parent);
-          ct = ASTNode_getType(child);
           if (ASTNode_isLogical(parent) || ASTNode_isRelational(parent)) {
-            group = !(pt == ct);
+            group = 0;
           }
           else {
+            pt = ASTNode_getType(parent);
+            ct = ASTNode_getType(child);
+
             group = !((pt == ct) || (pt == AST_PLUS || pt == AST_TIMES));
           }
         }
@@ -455,6 +447,7 @@ L3FormulaFormatter_formatOperator (StringBuffer_t *sb, const ASTNode_t *node)
 void
 L3FormulaFormatter_formatRational (StringBuffer_t *sb, const ASTNode_t *node, const L3ParserSettings_t *settings)
 {
+  char * units;
   StringBuffer_appendChar( sb, '(');
   StringBuffer_appendInt ( sb, ASTNode_getNumerator(node)   );
   StringBuffer_appendChar( sb, '/');
@@ -464,7 +457,9 @@ L3FormulaFormatter_formatRational (StringBuffer_t *sb, const ASTNode_t *node, co
   if (L3ParserSettings_getParseUnits(settings)) {
     if (ASTNode_hasUnits(node)) {
       StringBuffer_appendChar( sb, ' ');
-      StringBuffer_append( sb, ASTNode_getUnits(node));
+      units = ASTNode_getUnits(node);
+      StringBuffer_append( sb, units);
+      safe_free(units);
     }
   }
 }
@@ -479,6 +474,7 @@ L3FormulaFormatter_formatReal (StringBuffer_t *sb, const ASTNode_t *node, const
 {
   double value = ASTNode_getReal(node);
   int    sign;
+  char * units;
 
   if (ASTNode_isInteger(node)) {
     value = ASTNode_getInteger(node);
@@ -515,7 +511,9 @@ L3FormulaFormatter_formatReal (StringBuffer_t *sb, const ASTNode_t *node, const
   if (L3ParserSettings_getParseUnits(settings)) {
     if (ASTNode_hasUnits(node)) {
       StringBuffer_appendChar( sb, ' ');
-      StringBuffer_append( sb, ASTNode_getUnits(node));
+      units = ASTNode_getUnits(node);
+      StringBuffer_append( sb, units);
+      safe_free(units);
     }
   }
 }
@@ -606,22 +604,6 @@ L3FormulaFormatter_visit ( const ASTNode_t *parent,
   {
     L3FormulaFormatter_visitUNot(parent, node, sb, settings);
   }
-  else if (ASTNode_hasTypeAndNumChildren(node, AST_QUALIFIER_LOGBASE, 1))
-  {
-    L3FormulaFormatter_visit(node, ASTNode_getChild(node, 0), sb, settings);
-  }
-  else if (ASTNode_hasTypeAndNumChildren(node, AST_QUALIFIER_DEGREE, 1))
-  {
-    L3FormulaFormatter_visit(node, ASTNode_getChild(node, 0), sb, settings);
-  }
-  else if (ASTNode_hasTypeAndNumChildren(node, AST_SEMANTICS, 1))
-  {
-    L3FormulaFormatter_visit(node, ASTNode_getChild(node, 0), sb, settings);
-  }
-  else if (ASTNode_hasPackageOnlyInfixSyntax(node))
-  {
-    L3ParserSettings_visitPackageInfixSyntax(parent, node, sb, settings);
-  }
   else
   {
     L3FormulaFormatter_visitOther(parent, node, sb, settings);
@@ -840,31 +822,6 @@ L3FormulaFormatter_visitOther ( const ASTNode_t *parent,
   }
 }
 
-
-
-//This function determines if the node in question has unambiguous grammar; that
-// is, if it needs to worry about any of its components having parentheses.
-int
-L3FormulaFormatter_hasUnambiguousGrammar(const ASTNode_t *node, 
-                               const ASTNode_t *child, 
-                               const L3ParserSettings_t *settings)
-{
-  //All of the following situations have grammar that doesn't ever require the child
-  // to have parentheses added when it's a child of 'node'.
-
-  //Functions delimit their children with commas:
-  if (L3FormulaFormatter_isFunction(node, settings)) return 1;
-
-  //Packages have their own rules:
-  if (ASTNode_hasUnambiguousPackageInfixGrammar(node, child)) return 1;
-
-  //'8', the highest precedence, is only ever given to functions and other top-level 
-  // unambiguous objects.
-  if (getL3Precedence(child) == 8) return 1;
-  return 0;
-}
-
-
 //This function determines if the node in question should be
 // expressed in the form "functioname(children)" or if
 // it should be expressed as "child1 [symbol] child2 [symbol] child3"
@@ -925,13 +882,6 @@ L3FormulaFormatter_isFunction (const ASTNode_t *node,
   case AST_CONSTANT_FALSE:
   case AST_CONSTANT_PI:
   case AST_CONSTANT_TRUE:
-  /* new elements to the enum that should not get hit */
-  case AST_QUALIFIER_BVAR:
-  case AST_QUALIFIER_LOGBASE:
-  case AST_QUALIFIER_DEGREE:
-  case AST_SEMANTICS:
-  case AST_CONSTRUCTOR_PIECE:
-  case AST_CONSTRUCTOR_OTHERWISE:
     return 0;
 
   case AST_LOGICAL_XOR:
@@ -973,10 +923,6 @@ L3FormulaFormatter_isFunction (const ASTNode_t *node,
   case AST_FUNCTION_TANH:
   case AST_UNKNOWN:
     return 1;
-
-    /* this one will need work */
-  case AST_ORIGINATES_IN_PACKAGE:
-    return ASTNode_isPackageInfixFunction(node);
   }
   //Shouldn't ever get here
   assert(0);
